@@ -4,7 +4,7 @@ Display a dialog. Adds a new or modifies an existing operation
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2011, Loukas Avgeriou
+     Copyright 2008-2012, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ Display a dialog. Adds a new or modifies an existing operation
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 17 May 2011
+ last modified      : 17 Feb 2012
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -65,6 +65,12 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
     connect(uiM.pushButton_command, SIGNAL( pressed() ), this, SLOT(commandPressed() ) );        //show command pushButton
     connect(uiM.comboBox_Type, SIGNAL( currentIndexChanged(int) ), this, SLOT(TaskTypeChanged(int) ) ); //Actions when task type combo changes (hide/show stuff)
 
+    //Connect all include tab stuff changes with the disableExcludeTab SLOT
+    connect (uiM.checkBox_includeFile, SIGNAL (stateChanged(int) ), this , SLOT(disableExcludeTab()));
+    connect (uiM.lineEdit_includeFile, SIGNAL (textChanged(QString) ), this , SLOT(disableExcludeTab()));
+    connect (uiM.radioButton_includeOnly, SIGNAL (toggled(bool)), this , SLOT(disableExcludeTab()));
+    connect (uiM.radioButton_includeNormal, SIGNAL (toggled(bool)), this , SLOT(disableExcludeTab()));
+    
     //Connect all add list items buttons with the addListItem SLOT
     //Map all the pushButton signals and transmit a different integer depending on the pushbutton
     QSignalMapper *signalMapper2 = new QSignalMapper(this);
@@ -173,6 +179,8 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
     if (ArrayPosition < TotalOperations)    //if modify is pressed fill the fields first with existing operation data
         fillModifyWindow(Operation[ArrayPosition]);
     
+    disableExcludeTab();    // disable the exclude tab or nothing
+    
     StdArguments << "-h" << "--progress" << "--stats";    //These are the standard arguments used by rsync
 
     //initialize a completer for the lineEdits
@@ -350,9 +358,9 @@ void modifyDialog::okayPressed()
                 tr("That is not allowed because '/' does not have an actual name","message box message - line2")+" !!<br>"
                 "..."+tr("Please check the relevant box before proceeding","message box message - line3")+"<br><br>");
     }
-    //same for OS2
+    //same for OS2 or win
     if (((uiM.lineEdit_source -> text()).endsWith(":\\")) && (uiM.comboBox_Type -> currentIndex()==0) && (!uiM.checkBox_backupContents -> isChecked())
-        && (OS2running) )
+        && (notXnixRunning) )
     {
         modifyOK = FALSE;
         message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
@@ -470,7 +478,7 @@ void modifyDialog::commandPressed()
     dest=arguments[arguments.size()-1];
     while (count < arguments.size()-2)
     {
-        if (arguments[count].contains("-e ssh "))
+        if (arguments[count].contains("-e "+sshCommandPath+" "))
         {
             tempArgs.append("-e \"" + arguments[count].remove(0,3) + "\" ");
         }
@@ -568,6 +576,7 @@ void modifyDialog::addListItem(const int type)
             {
                     uiM.listWidget_include -> addItem(text);
                     uiM.lineEdit_includeAdd -> clear();
+                    disableExcludeTab();    // disable the exclude tab or not
                     return;
             }
 
@@ -609,6 +618,7 @@ void modifyDialog::addListItem(const int type)
             else
                 uiM.listWidget_include -> addItem(text);
             uiM.lineEdit_includeAdd -> clear();
+            disableExcludeTab();    // disable the exclude tab or not
             break;
             
         //options list add button
@@ -804,6 +814,7 @@ void modifyDialog::removeListItem(const int type)
             if (selected < 0)                            //if nothing is selected do nothing
                 return;
             uiM.listWidget_include-> takeItem(selected);
+            disableExcludeTab();    // disable the exclude tab or not
             break;
         //options list remove button
         case 2:
@@ -1172,6 +1183,22 @@ void modifyDialog::TaskTypeChanged(int type)
         uiM.checkBox_backupContents -> setVisible(TRUE);
     }
 }
+// Include tab stuff  changed=====================================================================================================
+// Enable/disable the "exclude" tab
+void modifyDialog::disableExcludeTab()
+{
+    bool enableIt = TRUE;
+    
+    // conditions to disable the exclude tab
+    if ( ( (uiM.listWidget_include -> count() > 0) || 
+       ((uiM.checkBox_includeFile->isChecked()) && ((uiM.lineEdit_includeFile->text()).size() >0)) ) &&
+       (uiM.radioButton_includeOnly -> isChecked()) )
+       
+       enableIt = FALSE;
+
+    uiM.toolBox_exclude -> setEnabled (enableIt);
+}
+
 //===================================================================================================================================================
 //------------------------------------------------------------------FUNCTIONS------------------------------------------------------------------------
 //===================================================================================================================================================
@@ -1246,6 +1273,7 @@ operation *modifyDialog::fillOperationArray()
     pTask -> SetExcludeLostFound    ( uiM.checkBox_excludeLostFound -> isChecked() );
     pTask -> SetExcludeSystem    ( uiM.checkBox_excludeSystem -> isChecked() );
     pTask -> SetExcludeTrash    ( uiM.checkBox_excludeTrash -> isChecked() );
+    pTask -> SetExcludeGVFS     ( uiM.checkBox_excludeGVFS -> isChecked() );
 
     count = 0;    //read exclude list one by one
     while ( count < (uiM.listWidget_exclude -> count()) )
@@ -1259,7 +1287,7 @@ operation *modifyDialog::fillOperationArray()
     //set include groupbox & all the info in there -----------------------------------------------------------------------------
     pTask -> SetIncludeFromFile    ( uiM.checkBox_includeFile -> isChecked() );
     pTask -> SetIncludeFile        ( uiM.lineEdit_includeFile -> text() );
-    pTask -> SetIncludeModeNormal    ( uiM.radioButton_includeNormal -> isChecked() );
+    pTask -> SetIncludeModeNormal  ( uiM.radioButton_includeNormal -> isChecked() );
     count = 0;    //read include list one by one
     while ( count < (uiM.listWidget_include -> count()) )
     {
@@ -1270,28 +1298,30 @@ operation *modifyDialog::fillOperationArray()
     pTask -> SetInclude();
 
     //set remote groupbox & all the info in there -----------------------------------------------------------------------------
-    pTask -> SetRemote        ( uiM.groupBox_remote -> isChecked() );
-    pTask -> SetRemoteModule    ( uiM.checkBox_remoteModule -> isChecked() );
-    pTask -> SetRemoteDestination    ( uiM.radioButton_remoteDestination -> isChecked() );
-    pTask -> SetRemoteSource    ( uiM.radioButton_remoteSource -> isChecked() );
-    pTask -> SetRemoteHost        ( uiM.lineEdit_remoteHost -> text() );
-    pTask -> SetRemoteUser        ( uiM.lineEdit_remoteUser -> text() );
-    pTask -> SetRemotePassword    ( uiM.lineEdit_rsyncPassword -> text() );
-    pTask -> SetRemoteSSH        ( uiM.checkBox_ssh -> isChecked() );
-    pTask -> SetRemoteSSHPassword    ( uiM.lineEdit_sshPassword -> text() );
-    pTask -> SetRemoteSSHPort    ( (uiM.lineEdit_sshPort -> text()).toInt() );
+    pTask -> SetRemote              ( uiM.groupBox_remote -> isChecked() );
+    pTask -> SetRemoteModule        ( uiM.checkBox_remoteModule -> isChecked() );
+    pTask -> SetRemoteDestination   ( uiM.radioButton_remoteDestination -> isChecked() );
+    pTask -> SetRemoteSource        ( uiM.radioButton_remoteSource -> isChecked() );
+    pTask -> SetRemoteHost          ( uiM.lineEdit_remoteHost -> text() );
+    pTask -> SetRemoteUser          ( uiM.lineEdit_remoteUser -> text() );
+    pTask -> SetRemotePassword      ( uiM.lineEdit_rsyncPassword -> text() );
+    pTask -> SetRemoteSSH           ( uiM.checkBox_ssh -> isChecked() );
+    pTask -> SetRemoteSSHPassword   ( uiM.lineEdit_sshPassword -> text() );
+    pTask -> SetRemoteSSHPort       ( (uiM.lineEdit_sshPort -> text()).toInt() );
 
     //set rsync options checkboxes -----------------------------------------------------------------------------------------------
-    pTask -> SetOptionsUpdate    ( uiM.checkBox_update -> isChecked() );
+    pTask -> SetOptionsUpdate       ( uiM.checkBox_update -> isChecked() );
     pTask -> SetOptionsOwnership    ( uiM.checkBox_ownership -> isChecked() );
-    pTask -> SetOptionsSymlinks    ( uiM.checkBox_symlinks -> isChecked() );
-    pTask -> SetOptionsPermissions    ( uiM.checkBox_permissions -> isChecked() );
-    pTask -> SetOptionsDevices    ( uiM.checkBox_devices -> isChecked() );
-    pTask -> SetOptionsCVS        ( uiM.checkBox_cvs -> isChecked() );
+    pTask -> SetOptionsSymlinks     ( uiM.checkBox_symlinks -> isChecked() );
+    pTask -> SetOptionsPermissions  ( uiM.checkBox_permissions -> isChecked() );
+    pTask -> SetOptionsDevices      ( uiM.checkBox_devices -> isChecked() );
+    pTask -> SetOptionsCVS          ( uiM.checkBox_cvs -> isChecked() );
     pTask -> SetOptionsHardLinks    ( uiM.checkBox_hardLinks -> isChecked() );
-    pTask -> SetOptionsFATntfs    ( uiM.checkBox_FATntfs -> isChecked() );
-    pTask -> SetOptionsDelete    ( uiM.checkBox_deleteAfter -> isChecked() );
-    pTask -> SetOptionsRecurse    ( uiM.checkBox_recurse -> isChecked() );
+    pTask -> SetOptionsFATntfs      ( uiM.checkBox_FATntfs -> isChecked() );
+    pTask -> SetOptionsDelete       ( uiM.checkBox_deleteAfter -> isChecked() );
+    pTask -> SetOptionsRecurse      ( uiM.checkBox_recurse -> isChecked() );
+    pTask -> SetOptionsSuper        ( uiM.checkBox_super -> isChecked() );
+    pTask -> SetOptionsNumericIDs   ( uiM.checkBox_numericIDs -> isChecked() );
     count = 0;    //read options list one by one
     while ( count < (uiM.listWidget_options -> count()) )
     {
@@ -1320,7 +1350,8 @@ operation *modifyDialog::fillOperationArray()
         pTask -> AddExecuteAfterListItemState(tempState);
         count++;
     }
-    pTask -> SetByPassWARNING    ( uiM.checkBox_byPassWarning -> isChecked() );
+    pTask -> SetByPassWARNING   ( uiM.checkBox_byPassWarning -> isChecked() );
+    pTask -> SetRepeatOnFail    ( uiM.spinBox_repeatOnFail -> value() );
 
     //append aguments -----------------------------------------------------------------------------------------------------------
     pTask -> SetArgs ( AppendArguments(pTask) );
@@ -1349,62 +1380,65 @@ void modifyDialog::fillModifyWindow(operation *pTask)
     if (pTask -> GetTypeSync())
         uiM.comboBox_Type -> setCurrentIndex(1);
 
-    uiM.lineEdit_source         -> setText    (pTask -> GetSource() );
-    uiM.lineEdit_destination     -> setText    (pTask -> GetDestination() );
+    uiM.lineEdit_source             -> setText    (pTask -> GetSource() );
+    uiM.lineEdit_destination        -> setText    (pTask -> GetDestination() );
     
-    uiM.spinBox_snapshotsKeep    -> setValue    (pTask -> GetKeepSnapshots());
+    uiM.spinBox_snapshotsKeep       -> setValue    (pTask -> GetKeepSnapshots());
 
-    uiM.checkBox_excludeFile     -> setChecked    (pTask -> GetExcludeFromFile() );
-    uiM.lineEdit_excludeFile     -> setText    (pTask -> GetExcludeFile() );
-    uiM.checkBox_excludeTemp     -> setChecked    (pTask -> GetExcludeTemp() );
-    uiM.checkBox_excludeCache     -> setChecked    (pTask -> GetExcludeCache() );
-    uiM.checkBox_excludeBackup     -> setChecked    (pTask -> GetExcludeBackup() );
-    uiM.checkBox_excludeMount     -> setChecked    (pTask -> GetExcludeMount() );
-    uiM.checkBox_excludeLostFound     -> setChecked    (pTask -> GetExcludeLostFound() );
-    uiM.checkBox_excludeSystem     -> setChecked    (pTask -> GetExcludeSystem() );
-    uiM.checkBox_excludeTrash     -> setChecked    (pTask -> GetExcludeTrash() );
+    uiM.checkBox_excludeFile        -> setChecked    (pTask -> GetExcludeFromFile() );
+    uiM.lineEdit_excludeFile        -> setText    (pTask -> GetExcludeFile() );
+    uiM.checkBox_excludeTemp        -> setChecked    (pTask -> GetExcludeTemp() );
+    uiM.checkBox_excludeCache       -> setChecked    (pTask -> GetExcludeCache() );
+    uiM.checkBox_excludeBackup      -> setChecked    (pTask -> GetExcludeBackup() );
+    uiM.checkBox_excludeMount       -> setChecked    (pTask -> GetExcludeMount() );
+    uiM.checkBox_excludeLostFound   -> setChecked    (pTask -> GetExcludeLostFound() );
+    uiM.checkBox_excludeSystem      -> setChecked    (pTask -> GetExcludeSystem() );
+    uiM.checkBox_excludeTrash       -> setChecked    (pTask -> GetExcludeTrash() );
+    uiM.checkBox_excludeGVFS        -> setChecked    (pTask -> GetExcludeGVFS() );
     count=0;
     while ( count < (pTask -> GetExcludeListSize()) )
     {
-        uiM.listWidget_exclude    -> addItem    (pTask -> GetExcludeListItem(count));
+        uiM.listWidget_exclude      -> addItem    (pTask -> GetExcludeListItem(count));
         count++;
     }
 
-    uiM.checkBox_includeFile     -> setChecked    (pTask -> GetIncludeFromFile() );
+    uiM.checkBox_includeFile        -> setChecked    (pTask -> GetIncludeFromFile() );
     uiM.radioButton_includeNormal     -> setChecked    (pTask -> GetIncludeModeNormal() );
     uiM.radioButton_includeOnly     -> setChecked    (!pTask -> GetIncludeModeNormal() );
-    uiM.lineEdit_includeFile     -> setText        (pTask -> GetIncludeFile() );
+    uiM.lineEdit_includeFile        -> setText        (pTask -> GetIncludeFile() );
     count=0;
     while ( count < (pTask -> GetIncludeListSize()) )
     {
-        uiM.listWidget_include    -> addItem    (pTask -> GetIncludeListItem(count));
+        uiM.listWidget_include      -> addItem    (pTask -> GetIncludeListItem(count));
         count++;
     }
 
-    uiM.groupBox_remote         -> setChecked    (pTask -> GetRemote() );
-    uiM.checkBox_remoteModule    -> setChecked    (pTask -> GetRemoteModule() );
+    uiM.groupBox_remote             -> setChecked    (pTask -> GetRemote() );
+    uiM.checkBox_remoteModule       -> setChecked    (pTask -> GetRemoteModule() );
     uiM.radioButton_remoteDestination-> setChecked    (pTask -> GetRemoteDestination() );
-    uiM.radioButton_remoteSource     -> setChecked    (pTask -> GetRemoteSource() );
-    uiM.lineEdit_remoteHost     -> setText    (pTask -> GetRemoteHost() );
-    uiM.lineEdit_remoteUser     -> setText    (pTask -> GetRemoteUser() );
-    uiM.lineEdit_rsyncPassword     -> setText    (pTask -> GetRemotePassword() );
-    uiM.checkBox_ssh         -> setChecked    (pTask -> GetRemoteSSH() );
-    uiM.lineEdit_sshPassword     -> setText    (pTask -> GetRemoteSSHPassword() );
+    uiM.radioButton_remoteSource    -> setChecked    (pTask -> GetRemoteSource() );
+    uiM.lineEdit_remoteHost         -> setText    (pTask -> GetRemoteHost() );
+    uiM.lineEdit_remoteUser         -> setText    (pTask -> GetRemoteUser() );
+    uiM.lineEdit_rsyncPassword      -> setText    (pTask -> GetRemotePassword() );
+    uiM.checkBox_ssh                -> setChecked    (pTask -> GetRemoteSSH() );
+    uiM.lineEdit_sshPassword        -> setText    (pTask -> GetRemoteSSHPassword() );
     if (pTask -> GetRemoteSSHPort() == 0)
-        uiM.lineEdit_sshPort     -> setText    ("");
+        uiM.lineEdit_sshPort        -> setText    ("");
     else
-        uiM.lineEdit_sshPort     -> setText    (countStr.setNum(pTask -> GetRemoteSSHPort()) );
+        uiM.lineEdit_sshPort        -> setText    (countStr.setNum(pTask -> GetRemoteSSHPort()) );
 
-    uiM.checkBox_update         -> setChecked    (pTask -> GetOptionsUpdate() );
-    uiM.checkBox_deleteAfter     -> setChecked    (pTask -> GetOptionsDelete() );
-    uiM.checkBox_recurse         -> setChecked    (pTask -> GetOptionsRecurse() );
-    uiM.checkBox_ownership         -> setChecked    (pTask -> GetOptionsOwnership() );
-    uiM.checkBox_symlinks         -> setChecked    (pTask -> GetOptionsSymlinks() );
-    uiM.checkBox_permissions     -> setChecked    (pTask -> GetOptionsPermissions() );
-    uiM.checkBox_devices         -> setChecked    (pTask -> GetOptionsDevices() );
-    uiM.checkBox_cvs             -> setChecked    (pTask -> GetOptionsCVS() );
-    uiM.checkBox_hardLinks         -> setChecked    (pTask -> GetOptionsHardLinks() );
-    uiM.checkBox_FATntfs         -> setChecked    (pTask -> GetOptionsFATntfs() );
+    uiM.checkBox_update             -> setChecked    (pTask -> GetOptionsUpdate() );
+    uiM.checkBox_deleteAfter        -> setChecked    (pTask -> GetOptionsDelete() );
+    uiM.checkBox_recurse            -> setChecked    (pTask -> GetOptionsRecurse() );
+    uiM.checkBox_ownership          -> setChecked    (pTask -> GetOptionsOwnership() );
+    uiM.checkBox_symlinks           -> setChecked    (pTask -> GetOptionsSymlinks() );
+    uiM.checkBox_permissions        -> setChecked    (pTask -> GetOptionsPermissions() );
+    uiM.checkBox_devices            -> setChecked    (pTask -> GetOptionsDevices() );
+    uiM.checkBox_cvs                -> setChecked    (pTask -> GetOptionsCVS() );
+    uiM.checkBox_hardLinks          -> setChecked    (pTask -> GetOptionsHardLinks() );
+    uiM.checkBox_FATntfs            -> setChecked    (pTask -> GetOptionsFATntfs() );
+    uiM.checkBox_super              -> setChecked    (pTask -> GetOptionsSuper() );
+    uiM.checkBox_numericIDs         -> setChecked    (pTask -> GetOptionsNumericIDs() );
     count=0;
     while ( count < (pTask -> GetOptionsListSize()) )
     {
@@ -1435,7 +1469,8 @@ void modifyDialog::fillModifyWindow(operation *pTask)
             uiM.listWidget_executeAfter -> currentItem() -> setCheckState(Qt::Unchecked);
         count++;
     }
-    uiM.checkBox_byPassWarning     -> setChecked    (pTask -> GetByPassWARNING() );
+    uiM.checkBox_byPassWarning      -> setChecked   ( pTask -> GetByPassWARNING() );
+    uiM.spinBox_repeatOnFail        -> setValue     ( pTask -> GetRepeatOnFail() );
 }
 
 // modifyTrailing ===========================================================================================================
@@ -1447,22 +1482,22 @@ void modifyDialog::modifyTrailing()
     QString sourceDir   = uiM.lineEdit_source -> text();
     QString destDir     = uiM.lineEdit_destination -> text();
     
-    // Check if a drive letter is declared at OS/2 (eg c:) and add a trailing slash
-    if (OS2running)
+    // Check if a drive letter is declared at OS/2 or win (eg c:) and add a trailing slash
+    if (notXnixRunning)
     {
         if (sourceDir.endsWith(":"))    sourceDir.append(SLASH);
         if (destDir.endsWith(":"))      destDir.append(SLASH);
     }
 
-    if ((uiM.comboBox_Type -> currentIndex()==0) && (uiM.checkBox_backupContents -> isChecked()))    //Directory by contents
+    if ((uiM.comboBox_Type -> currentIndex()==0) && (uiM.checkBox_backupContents -> isChecked()))           //Directory by contents
     {
-        if ( (!sourceDir.endsWith(SLASH)) && (sourceDir != ""))     sourceDir.append(SLASH);
-        if ( (!destDir.endsWith(SLASH)) && (destDir != ""))         destDir.append(SLASH);
+            if ( (!sourceDir.endsWith(SLASH)) && (sourceDir != ""))     sourceDir.append(SLASH);
+            if ( (!destDir.endsWith(SLASH)) && (destDir != ""))         destDir.append(SLASH);
     }
 
     if ((uiM.comboBox_Type -> currentIndex()==0) && (!uiM.checkBox_backupContents -> isChecked()))        //Directory by name
     {
-        if (OS2running) //OS2 uses normal slashes "\" not unix ones "/"
+        if (notXnixRunning) //OS2 & win uses normal slashes "\" not unix ones "/"
         {
             if ( (sourceDir.endsWith(SLASH)) && (!sourceDir.endsWith(":"+SLASH)) )      sourceDir.chop(1);
             if ( (!destDir.endsWith(SLASH)) && (destDir != "") )                        destDir.append(SLASH);
@@ -1480,11 +1515,19 @@ void modifyDialog::modifyTrailing()
         if ( (!sourceDir.endsWith(SLASH)) && (sourceDir != ""))   sourceDir.append(SLASH);
         if ( (!destDir.endsWith(SLASH)) && (destDir != ""))       destDir.append(SLASH);
         
-        uiM.checkBox_deleteAfter     -> setChecked    (FALSE);
+        uiM.checkBox_deleteAfter    -> setChecked    (FALSE);
         uiM.checkBox_update         -> setChecked    (TRUE);
-        uiM.checkBox_ownership         -> setChecked    (TRUE);
+        uiM.checkBox_ownership      -> setChecked    (TRUE);
         uiM.checkBox_permissions    -> setChecked    (TRUE);
     }
+    
+    if (WINrunning)     // some more adjustments for windows when the user wants to declare directly paths with "/" instead of "\" (normally for remote)
+    {      
+        if (sourceDir.contains("/"))    sourceDir.replace(SLASH,"/");
+        if (sourceDir.endsWith("//"))   sourceDir.chop(1);
+        if (destDir.contains("/"))      destDir.replace(SLASH,"/");
+        if (destDir.endsWith("//"))     destDir.chop(1);
+    }
 
     uiM.lineEdit_source -> setText(sourceDir);
     uiM.lineEdit_destination -> setText(destDir);
@@ -1494,7 +1537,7 @@ void modifyDialog::modifyTrailing()
 // function to change / to \ for OS2 (normaly when file dialog is used)
 QString modifyDialog::modifyOS2Slashes(QString pathToModify)
 {    
-    if (OS2running)
+    if (notXnixRunning)
         pathToModify.replace("/",SLASH);
     
     return pathToModify;
