@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2011, Loukas Avgeriou
+     Copyright 2008-2012, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 30 Jan 2011
+ last modified      : 13 Feb 2012
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -52,11 +52,15 @@ class operation
             itsIncludeModeNormal = FALSE;
             itsByPassWARNING = FALSE;
             itsCloneWARNING = TRUE;
+            itsRepeatOnFail = 0;
             itsKeepSnapshots = 1;
             itsSnapshotsList.clear();
             itsOptionsFATntfs = FALSE;
+            itsOptionsSuper = FALSE;
+            itsOptionsNumericIDs = FALSE;
             itsIncludeFromFile = FALSE;
             itsExcludeFromFile = FALSE;
+            itsExcludeGVFS = FALSE;
             itsExecuteBeforeList.clear();
             itsExecuteBeforeListState.clear();
             itsExecuteAfterList.clear();
@@ -79,6 +83,7 @@ class operation
         bool GetPerform () const                {return itsPerform;}
         bool GetByPassWARNING () const          {return itsByPassWARNING;}
         bool GetCloneWARNING () const           {return itsCloneWARNING;}
+        int GetRepeatOnFail() const             {return itsRepeatOnFail;}
 
         QDateTime GetLastExecutionTime() const  {return itsLastExecutionTime;}
         int GetLastExecutionErrors() const      {return itsLastExecutionErrors;}
@@ -106,6 +111,7 @@ class operation
         bool GetExcludeLostFound() const        {return itsExcludeLostFound;}
         bool GetExcludeSystem() const           {return itsExcludeSystem;}
         bool GetExcludeTrash() const            {return itsExcludeTrash;}
+        bool GetExcludeGVFS() const             {return itsExcludeGVFS;}
         int GetExcludeListSize () const         {return itsExcludeList.size();}
         QString GetExcludeListItem (int itemPosition) const {return itsExcludeList.value(itemPosition);}
 
@@ -137,6 +143,8 @@ class operation
         bool GetOptionsCVS () const             {return itsOptionsCVS;}
         bool GetOptionsHardLinks () const       {return itsOptionsHardLinks;}
         bool GetOptionsFATntfs() const          {return itsOptionsFATntfs;}
+        bool GetOptionsSuper() const            {return itsOptionsSuper;}
+        bool GetOptionsNumericIDs() const       {return itsOptionsNumericIDs;}
         int GetOptionsListSize () const         {return itsOptionsList.size();}
         QString GetOptionsListItem (int itemPosition) const {return itsOptionsList.value(itemPosition);}
 
@@ -163,6 +171,7 @@ class operation
         void SetPerform(bool perform)                       {itsPerform = perform;}
         void SetByPassWARNING(bool ByPassWARNING)           {itsByPassWARNING = ByPassWARNING;}
         void SetCloneWARNING(bool CloneWARNING)             {itsCloneWARNING = CloneWARNING;}
+        void SetRepeatOnFail(int RepeatOnFail)              {itsRepeatOnFail = RepeatOnFail;}
 
         // last execution time & errors
         void SetLastExecutionTime(QDateTime lastTime)       {itsLastExecutionTime = lastTime;}
@@ -198,7 +207,7 @@ class operation
         // Exclude boolean
         void SetExclude()                      { if ( ((itsExcludeFromFile) && !(itsExcludeFile=="")) || (itsExcludeTemp)||(itsExcludeCache)||(itsExcludeBackup)||
                                     (itsExcludeMount)||(itsExcludeLostFound)||(itsExcludeSystem)||
-                                    (itsExcludeTrash)||(itsExcludeList.size()>0) )
+                                    (itsExcludeTrash)||(itsExcludeGVFS)||(itsExcludeList.size()>0) )
                                         itsExclude = TRUE;
                                     else     itsExclude = FALSE; }
         // Exclude templates
@@ -209,6 +218,7 @@ class operation
         void SetExcludeLostFound(bool ExcludeLostFound)     { itsExcludeLostFound = ExcludeLostFound;}
         void SetExcludeSystem(bool ExcludeSystem)           { itsExcludeSystem = ExcludeSystem;}
         void SetExcludeTrash(bool ExcludeTrash)             { itsExcludeTrash = ExcludeTrash;}
+        void SetExcludeGVFS(bool ExcludeGVFS)               { itsExcludeGVFS = ExcludeGVFS;}
         // Exclude from file
         void SetExcludeFromFile(bool ExcludeFromFile)       { itsExcludeFromFile = ExcludeFromFile;}
         void SetExcludeFile(QString ExcludeFile)            { itsExcludeFile = ExcludeFile;}
@@ -253,6 +263,8 @@ class operation
         void SetOptionsCVS (bool OptionsCVS)                { itsOptionsCVS = OptionsCVS;}
         void SetOptionsHardLinks (bool OptionsHardLinks)    { itsOptionsHardLinks = OptionsHardLinks;}
         void SetOptionsFATntfs (bool OptionsFATntfs)        { itsOptionsFATntfs = OptionsFATntfs;}
+        void SetOptionsSuper (bool OptionsSuper)            { itsOptionsSuper = OptionsSuper;}
+        void SetOptionsNumericIDs (bool OptionsNumeriIDs)   { itsOptionsNumericIDs = OptionsNumeriIDs;}
         // Command options list - user defined
         void AddOptionsListItem (QString itemText)          { itsOptionsList.append(itemText);}
 
@@ -277,6 +289,7 @@ class operation
         bool itsPerform;
         bool itsByPassWARNING;
         bool itsCloneWARNING;
+        int itsRepeatOnFail;
         QDateTime itsLastExecutionTime;
         int itsLastExecutionErrors;
         QStringList itsSnapshotsList;
@@ -299,6 +312,7 @@ class operation
         bool itsExcludeLostFound;
         bool itsExcludeSystem;
         bool itsExcludeTrash;
+        bool itsExcludeGVFS;
         bool itsExcludeFromFile;
         QString itsExcludeFile;
         QStringList itsExcludeList;
@@ -330,6 +344,8 @@ class operation
         bool itsOptionsCVS;
         bool itsOptionsHardLinks;
         bool itsOptionsFATntfs;
+        bool itsOptionsSuper;
+        bool itsOptionsNumericIDs;
         QStringList itsOptionsList;
 
         QStringList itsExecuteBeforeList;
